@@ -159,7 +159,7 @@ create_payload = gql(
     """
 )
 create_operator_fragment = """
-    fragment create_operator_fragment on createOperator {
+    fragment create_operator_fragment on OperatorOutput {
         active
         creation_time
         deleted
@@ -234,7 +234,7 @@ update_operator_in_operation_fragment = """
     }
 """
 create_operation_fragment = """
-    fragment create_operation_fragment on createOperation {
+    fragment create_operation_fragment on createOperationOutput {
         status
         error
         operation{
